#!/bin/bash
# ATMEL Wireless Card Setup for linux
# Copyright 2001 (c) ATMEL Hellas

CONFIG_MK=config.mk
CONFIG_H=config.h

function Checkxforms ()
{
	if [ -r /usr/include/X11/Xlib.h -o -r /usr/X11R6/include/X11/Xlib.h ]; then
		for f in /usr/{X11/,X11R6/,local/,}lib/libforms.{so,a} ; do
			if [ -r $f ]; then break; fi
		done
		for g in /usr/{X11/,X11R6/,local/,}include/{,,X11/}forms.h ; do
			if [ -r $g ]; then break; fi
		done
		if [ -r $f -a -r $g ] ; then
			HAS_FORMS=y
		else
			cd misc
			bunzip2 forms.tar.bz2 &>/dev/null
			tar xvf forms.tar &>/dev/null
			bzip2 forms.tar &>/dev/null
			cd xforms
			make -s
			cd ..
			cd ..
			HAS_FORMS=y
		fi
	else
		echo "X Windows include files missing"
	fi
}

function CheckKernelVersion
{
    if [ -d $1 ]; then
        if [ -f $1/Makefile ]; then
            for TAG in VERSION PATCHLEVEL SUBLEVEL EXTRAVERSION ; do
                eval `sed -ne "/^$TAG/s/[ 	]//gp" $1/Makefile`
            done
            FV="$VERSION.$PATCHLEVEL.$SUBLEVEL$EXTRAVERSION"
            if [ "$LV" = "$FV" ]; then
                if [ "$PATH_FOUND" = "n" ]; then
                    PATH_FOUND=y
                    SRCPATH=$1
                fi
            fi
        fi
    fi
}

PID=0
VID=0
BoardType=0
BoardDefine=0
BoardTypeLib=0
function GetPIDVID()
{
	echo -n "Give the desired Product ID : 0x"
	read PID
	echo -n "Give the desired Vendor  ID : 0x"
	read VID
	echo "What type of board do you have?"
	echo -n "(1: RFMD, 2:Intersil 3861, 3:Intersil 3863)?"
	read BoardType
	F=newconfig.h
	if [ -f $F ]; then rm -f $F; fi
	grep -v 'ine VNetPID_CU' usb_src/config.h |grep -v 'ine VNetVID_CU' >usb_src/config.h
	while read A
	do
		FOUND=$(echo "$A"|grep -c 'define __con')
		TABN=$(echo "$A"|grep -c USB_DEVICE)
		EMBLOCK=$(echo "$A"|grep -c '{ }')
		if [ $FOUND -eq 1 ]; then
			echo "$A" >> $F
			echo >> $F
			echo "#define VNetVID_CUSTOM 0x$VID" >> $F
			echo "#define VNetPID_CUSTOM 0x$PID" >> $F
			echo "" >> $F
		else
			if [ $TABN -eq 1 ] || [ $EMBLOCK -eq 1 ]; then
				echo -e "\t$A" >> $F
			else
				echo "$A" >>  $F
			fi
		fi
	done < usb_src/config.h
	rm -f usb_src/config.h
	mv $F usb_src/config.h
	case $BoardType in
	1 )
		BoardTypeLib=vnetusbRFMD
		BoardDefine=-DRFMD
		;;
	2 )		
		BoardTypeLib=vnetusb
		;;
	3 )
		BoardTypeLib=vnetusbi3863
		BoardDefine=-Di3863
		;;
	* )	
		echo "Invalid input gived. Please retry"
		return
		;;
	esac
}


SRCPATH=null
PCMCIA_SRC=null
PATH_FOUND=n
HAS_FORMS=n
MAN_PATH=$(man -w ls|xargs dirname)
MPA=/usr/src
CONFIGP="/etc/pcmcia"
USB_CONFIG="/etc/hotplug"
LV=$(uname -r)

USBDES="/lib/modules/$LV/kernel/drivers/usb"
if [ ! -d $USBDES ]; then
	mkdir $USBDES
fi
PCMCIADES="/lib/modules/$LV/pcmcia"
PCIDES="/lib/modules/$LV/kernel/drivers/net"
MODPROBE_PATH=$(which modprobe)

rm -f $CONFIG_MK
rm -f $CONFIG_H
Checkxforms

if [ "$1" == "-v" ]; then
	GetPIDVID
fi
if [ -L /lib/modules/$LV/build ]&&[ -f /lib/modules/$LV/build/Makefile ]; then
    SRCPATH=/lib/modules/$LV/build
else
    for f in $MPA/*; do CheckKernelVersion $f ; done
fi

echo "Kernel Version Running $LV"

if [ "$SRCPATH" = "null" ]; then
    echo -e "Kernel Source Directory Not Found. Please give path : \c"
    read SRCPATH
    if [ ! -d $SRCPATH ]; then
        echo "Invalid Path"
        rm -f config.mk
    fi
else
    echo Found Kernel Source Directory "($SRCPATH)"
fi

if [ $# -gt 0 ]; then
    PCMCIA_IN_KERNEL=$(grep -c CONFIG_PCMCIA= $SRCPATH/.config)

    if [ $PCMCIA_IN_KERNEL -eq 1 ] ; then
	PCMCIA_SRC=$SRCPATH
    else
	for f in $SRCPATH/pcmcia*; do
	    if [ -L $f ]; then
		if [ -d $f/include ]; then
		    PCMCIA_SRC=$f
		    break
	    fi
	    fi

	    if [ -d $f ]; then
	    if [ -d $f/include ]; then
		    PCMCIA_SRC=$f
		    break
	    fi
	    fi
	done
	if [ "$PCMCIA_SRC" = "null" ]; then
	    echo "Pcmcia card services source needed but not found"
	    echo "Please give desired path.If you have the kernel"
	    echo "support for the PCMCIA card services you still"
	    echo "have to install the corresponding version of "
	    echo "the card services"
	    read PCMCIA_SRC
	fi

	if [ ! -d $PCMCIA_SRC/include ] && [ "$PCMCIA_SRC" != "" ]; then
	    echo "Invalid directory. Check pcmcia source path and retry"
	    exit -1;
	fi
    fi
fi

echo LINUX = $SRCPATH >> $CONFIG_MK
echo HAS_FORMS = $HAS_FORMS >> $CONFIG_MK
if [ $# -gt 0 ]; then
    echo PCMCIA_DES = $PCMCIADES >> $CONFIG_MK
    echo PCMCIA_CONFIG = $CONFIGP >> $CONFIG_MK
    echo PCMCIA_SRC = $PCMCIA_SRC >> $CONFIG_MK
fi

echo PCI_DES = $PCIDES >> $CONFIG_MK
echo USB_DES = $USBDES >> $CONFIG_MK
echo USB_CONFIG = $USB_CONFIG >> $CONFIG_MK
echo MAN_PATH = $MAN_PATH >> $CONFIG_MK
if [ "$1" = "-v" ]; then
echo BoardDefine = $BoardDefine >> $CONFIG_MK
echo BoardTypeLib = $BoardTypeLib >> $CONFIG_MK
fi
echo >> $CONFIG_MK
echo >> $CONFIG_MK
